@@ -3,30 +3,36 @@
 """Support for testing code that uses Twisted."""
 
 __all__ = [
-    # Matchers
-    "succeeded",
-    "failed",
-    "has_no_result",
     # Running tests
     "AsynchronousDeferredRunTest",
     "AsynchronousDeferredRunTestForBrokenTwisted",
-    "SynchronousDeferredRunTest",
     "CaptureTwistedLogs",
+    # Deferred utilities
+    "DeferredNotFired",
+    "SynchronousDeferredRunTest",
     "assert_fails_with",
+    "extract_result",
+    "failed",
     "flush_logged_errors",
+    "has_no_result",
+    # Matchers
+    "succeeded",
 ]
 
+from ._deferred import (
+    DeferredNotFired,
+    extract_result,
+)
 from ._matchers import (
-    succeeded,
     failed,
     has_no_result,
+    succeeded,
 )
-
 from ._runtest import (
     AsynchronousDeferredRunTest,
     AsynchronousDeferredRunTestForBrokenTwisted,
-    SynchronousDeferredRunTest,
     CaptureTwistedLogs,
+    SynchronousDeferredRunTest,
     assert_fails_with,
     flush_logged_errors,
 )
